pub trait ChainError<O: ErrorCategory, Tag> {
// Required method
fn chain(self, error_code: O) -> Error<O>;
}Expand description
A trait that allows chaining of Error and DynError values and
any value of a type that implements ErrorCategory.
Required Methods
Sourcefn chain(self, error_code: O) -> Error<O>
fn chain(self, error_code: O) -> Error<O>
Chain this error with the supplied error_code.
Panics
If the error category O is not linked with the ErrorCategory
of the most recent error code, this function will panic.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".